@@ -1,3 +1,3 @@
-.First.lib <- function(lib, pkg) {
+.onLoad <- function(lib, pkg) {
        warning("package regtest is under development and still may change considerably")
 }
